@@ -25,6 +25,7 @@ try:
     from collections.abc import Iterable
 except ImportError:
     from collections import Iterable
+from posixpath import join
 
 
 # version of the openPMD standard
@@ -65,6 +66,13 @@ def parse_cmd(argv):
     return(file_name, verbose, force_extension_pic)
 
 
+def join_path(path, other_path):
+    """ This joins openPMD internal paths.
+
+    Contrary to os.path.join, they are always forward-slashes"""
+    return join(path, other_path)
+
+
 def open_file(file_name):
     if h5.is_hdf5(file_name):
         f = h5.File(file_name, "r")
@@ -523,8 +531,8 @@ def check_base_path(f, iteration, v, extensionStates):
     bp = f[base_path]
 
     # Check for the attributes of the STANDARD.md
-    result_array += test_attr(bp, v, "required", "time", [np.float32, np.float64, np.float128])
-    result_array += test_attr(bp, v, "required", "dt", [np.float32, np.float64, np.float128])
+    result_array += test_attr(bp, v, "required", "time", [np.single, np.double, np.longdouble])
+    result_array += test_attr(bp, v, "required", "dt", [np.single, np.double, np.longdouble])
     result_array += test_attr(bp, v, "required", "timeUnitSI", np.float64)
 
     return(result_array)
@@ -570,7 +578,7 @@ def check_meshes(f, iteration, v, extensionStates):
                   "(will not search for mesh records)")
 
     if meshes_path:
-        if os.path.join( base_path, meshes_path) != ( base_path + meshes_path ):
+        if join_path( base_path, meshes_path) != ( base_path + meshes_path ):
             print("Error: `basePath`+`meshesPath` seems to be malformed "
                 "(is `basePath` absolute and ends on a `/` ?)")
             return( np.array([1, 0]) )
@@ -625,14 +633,14 @@ def check_meshes(f, iteration, v, extensionStates):
         if is_scalar_record(field) :   # If the record is a scalar field
             result_array += test_component(field, v)
             result_array += test_attr(field, v,
-                                "required", "position", np.ndarray, [np.float32, np.float64, np.float128])
+                                "required", "position", np.ndarray, [np.single, np.double, np.longdouble])
         else:                          # If the record is a vector field
             # Loop over the components
             for component_name in list(field.keys()) :
                 component = field[component_name]
                 result_array += test_component(component, v)
                 result_array += test_attr(component, v,
-                                "required", "position", np.ndarray, [np.float32, np.float64, np.float128])
+                                "required", "position", np.ndarray, [np.single, np.double, np.longdouble])
 
     # Check for the attributes of the PIC extension,
     # if asked to do so by the user 
@@ -731,7 +739,7 @@ def check_particles(f, iteration, v, extensionStates) :
                   "(will not search for particle records)")
 
     if particles_path:
-        if os.path.join( base_path, particles_path) !=  \
+        if join_path( base_path, particles_path) !=  \
             ( base_path + particles_path ) :
             print("Error: `basePath`+`particlesPath` seems to be malformed "
                 "(is `basePath` absolute and ends on a `/` ?)")
@@ -817,7 +825,7 @@ def check_particles(f, iteration, v, extensionStates) :
         # Check the attributes associated with the PIC extension
         if extensionStates['ED-PIC'] :
             result_array += test_attr(species, v, "required",
-                                      "particleShape", [np.float32, np.float64, np.float128])
+                                      "particleShape", [np.single, np.double, np.longdouble])
             result_array += test_attr(species, v, "required",
                                       "currentDeposition", np.string_)
             result_array += test_attr(species, v, "required",
@@ -840,7 +848,7 @@ def check_particles(f, iteration, v, extensionStates) :
                 result_array += test_attr(species[record], v,
                         "required", "unitDimension", np.ndarray, np.float64)
                 result_array += test_attr(species[record], v, "required",
-                                          "timeOffset", [np.float32, np.float64, np.float128])
+                                          "timeOffset", [np.single, np.double, np.longdouble])
                 if extensionStates['ED-PIC'] :
                     result_array += test_attr(species[record], v, "required",
                                               "weightingPower", np.float64)
@@ -853,7 +861,7 @@ def check_particles(f, iteration, v, extensionStates) :
                 else : # Vector record
                     # Loop over the components
                     for component_name in list(species[record].keys()):
-                        dset = species[ os.path.join(record, component_name) ]
+                        dset = species[ join_path(record, component_name) ]
                         result_array += test_component(dset, v)
 
             # weighting's attributes are fixed
